Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
path: root/source
diff options
context:
space:
mode:
authorCampbell Barton <ideasman42@gmail.com>2013-07-03 08:47:50 +0400
committerCampbell Barton <ideasman42@gmail.com>2013-07-03 08:47:50 +0400
commit905cb1639ad8f82502ecf9f1701963972f96080e (patch)
tree0df9cd680df9076b6509d155a15bc700784d5bee /source
parentffaebe2237d4cdc84dc196cbbf60e1a96b0af3e4 (diff)
update doxygen congfig and tweaks to warnings when running doxygen.
Diffstat (limited to 'source')
-rw-r--r--source/blender/editors/space_view3d/view3d_project.c19
-rw-r--r--source/blender/freestyle/intern/stroke/StrokeIterators.h2
2 files changed, 11 insertions, 10 deletions
diff --git a/source/blender/freestyle/intern/stroke/StrokeIterators.h b/source/blender/freestyle/intern/stroke/StrokeIterators.h
index 2f9691be7dd..1082adfbf41 100644
--- a/source/blender/freestyle/intern/stroke/StrokeIterators.h
+++ b/source/blender/freestyle/intern/stroke/StrokeIterators.h
@@ -88,7 +88,7 @@ public:
/*! operator=
* \attention In the scripting language, you must call \code it2 = StrokeVertexIterator(it1) \endcode instead of
- * \code it2 = it1 \endcode, where \a it1 and \a it2 are 2 StrokeVertexIterator.
+ * \code it2 = it1 \endcode where \a it1 and \a it2 are 2 StrokeVertexIterator.
* Otherwise, incrementing \a it1 will also increment \a it2.
*/
StrokeVertexIterator& operator=(const StrokeVertexIterator& vi)
diff --git a/source/blender/editors/space_view3d/view3d_project.c b/source/blender/editors/space_view3d/view3d_project.c
index 974006d45db..5e71913ea4a 100644
--- a/source/blender/editors/space_view3d/view3d_project.c
+++ b/source/blender/editors/space_view3d/view3d_project.c
@@ -310,8 +310,9 @@ float ED_view3d_calc_zfac(const RegionView3D *rv3d, const float co[3], bool *r_f
* \param ar The region (used for the window width and height).
* \param v3d The 3d viewport (used for near clipping value).
* \param mval The area relative 2d location (such as event->mval, converted into float[2]).
* \param ray_start The world-space starting point of the segment.
* \param ray_normal The normalized world-space direction of towards mval.
* \return success, false if the segment is totally clipped.
*/
bool ED_view3d_win_to_ray(const ARegion *ar, View3D *v3d, const float mval[2],
@@ -504,7 +505,7 @@ void ED_view3d_win_to_vector(const ARegion *ar, const float mval[2], float out[3
* \return success, false if the segment is totally clipped.
*/
bool ED_view3d_win_to_segment(const ARegion *ar, View3D *v3d, const float mval[2],
- float ray_start[3], float ray_end[3], const bool do_clip)
+ float r_ray_start[3], float r_ray_end[3], const bool do_clip)
{
RegionView3D *rv3d = ar->regiondata;
@@ -512,9 +513,9 @@ bool ED_view3d_win_to_segment(const ARegion *ar, View3D *v3d, const float mval[2
float vec[3];
ED_view3d_win_to_vector(ar, mval, vec);
- copy_v3_v3(ray_start, rv3d->viewinv[3]);
- madd_v3_v3v3fl(ray_start, rv3d->viewinv[3], vec, v3d->near);
- madd_v3_v3v3fl(ray_end, rv3d->viewinv[3], vec, v3d->far);
+ copy_v3_v3(r_ray_start, rv3d->viewinv[3]);
+ madd_v3_v3v3fl(r_ray_start, rv3d->viewinv[3], vec, v3d->near);
+ madd_v3_v3v3fl(r_ray_end, rv3d->viewinv[3], vec, v3d->far);
}
else {
float vec[4];
@@ -525,13 +526,13 @@ bool ED_view3d_win_to_segment(const ARegion *ar, View3D *v3d, const float mval[2
mul_m4_v4(rv3d->persinv, vec);
- madd_v3_v3v3fl(ray_start, vec, rv3d->viewinv[2], 1000.0f);
- madd_v3_v3v3fl(ray_end, vec, rv3d->viewinv[2], -1000.0f);
+ madd_v3_v3v3fl(r_ray_start, vec, rv3d->viewinv[2], 1000.0f);
+ madd_v3_v3v3fl(r_ray_end, vec, rv3d->viewinv[2], -1000.0f);
}
/* bounds clipping */
if (do_clip && (rv3d->rflag & RV3D_CLIPPING)) {
- if (clip_segment_v3_plane_n(ray_start, ray_end, rv3d->clip, 6) == false) {
+ if (clip_segment_v3_plane_n(r_ray_start, r_ray_end, rv3d->clip, 6) == false) {
return false;
}
}
@@ -310,8 +310,9 @@ float ED_view3d_calc_zfac(const RegionView3D *rv3d, const float co[3], bool *r_f
* \param v3d The 3d viewport (used for near clipping value).
* \param mval The area relative 2d location (such as event->mval, converted into float[2]).
- * \param ray_start The world-space starting point of the segment.
- * \param ray_normal The normalized world-space direction of towards mval.
+ * \param r_ray_start The world-space starting point of the segment.
+ * \param r_ray_normal The normalized world-space direction of towards mval.
+ * \param do_clip Optionally clip the ray by the view clipping planes.
* \return success, false if the segment is totally clipped.
*/